let data_log;
let hPunkte = []; // das Array der Helligkeitspunkte

function preload() {
    // einlesen der Werte in die Variable "data_log"
    // relative Pfade beachten!
    data_log = loadTable('./daten/data_log.csv');
}

function setup() {
    const meinCanvas = createCanvas(950, 470);
    meinCanvas.parent('canvasContainer');

    background(240);

    // Roboto als lokaler Webfont eingebunden!
    textFont('roboto');
    textSize(16);

    noStroke();

    // wieviele Zeilen enthält die Datei "data_log.csv"
    let anzahl = data_log.getRowCount();

    // liest alle Helligkeitswerte in das Array ein
    // diese befinden sich in jeder Zeile an der 4. Stelle
    // z.B. "2019-05-27,10:30:01,Helligkeit,144"
    // da hier bei Null angefangen wird zu zählen, hier "3" verwenden
    for (let i = 0; i < anzahl; i++) {
        hPunkte[i] = data_log.getNum(i, 3);
    }

    // ======================== Settings zur Darstellung ========================

    // Breite des Rechtecks abhängig von Breite des Sketches und Anzahl der Einträge
    // "40" ist eine Schätzung, so dass der Graph nicht rechts aus dem Sketch läuft…
    let b = (width - 40 - anzahl) / anzahl;
    let a = b + 1; // Abstand der Rechtecke
    const anfangX = 30; // rechte Kante der Rechtecke usw.
    const anfangY = 40; // obere Kante der Rechtecke usw.
    const factor = 0.4; // vertikaler Skalierungsfaktor, weil Graph sonst sehr hoch ist!

    // ==========================================================================

    // Überschrift
    fill(0);
    text(
        `Alle Helligkeitswerte als Graph: Die Tabelle enthält aktuell ${anzahl} Datensätze`,
        anfangX,
        anfangY - 13
    );

    // Hellgraue Rechtecke im Hintergrund hilft der Lesbarkeit, geben möglichen Max-Wert an
    fill(220);
    for (let i = 0; i < anzahl; i++) {
        // "1024" ist der Maximal-Wert, den die Fotozelle erreichen kann
        rect(anfangX + i * a, anfangY, b, 1024 * factor);
    }

    for (let i = 0; i < anzahl; i++) {
        // zeichnen der Rechtecke, abhängig vom Helligkeitswert
        fill('orange');
        rect(anfangX + i * a, anfangY, b, hPunkte[i] * factor);
    }

    // 4 waagrechte Linien alle 100px ("skala") zur Orientierung
    // als letztes gezeichnet, damit oberhalb der Rechteck-Flächen
    stroke(255);
    let skala = 100;
    for (let i = 0; i < 11; i++) {
        line(anfangX, anfangY + skala * i * factor, width - 10, anfangY + skala * i * factor);
    }

    // Beschriftung der Skala
    noStroke();
    fill(100);
    textSize(12);
    textAlign(RIGHT);
    for (let i = 0; i < 11; i++) {
        text(100 * i, anfangX - 3, anfangY + 5 + i * skala * factor);
    }
}
